==> jc-1.4.0.tar.gz: java/util/LinkedHashMap__24LinkedHashEntry.h <==
// class java.util.LinkedHashMap$LinkedHashEntry

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 166fe0b0ec37f0c9 java_util_AbstractMap__24BasicMapEntry
// @dep_class 5ed7b26c5166f525 java_util_HashMap__24HashEntry
// @dep_class 773b37c7a42544c8 java_util_LinkedHashMap__24LinkedHashEntry

// header file dependencies
// @dep_header java_util_HashMap__24HashEntry

#include "java/util/HashMap__24HashEntry.h"

#ifndef _JC_java_util_LinkedHashMap__24LinkedHashEntry_H_
#define _JC_java_util_LinkedHashMap__24LinkedHashEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedHashMap$object;
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object;

// Typedefs
typedef struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_refs	_jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_refs;
typedef struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_nonrefs	_jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_nonrefs;
typedef struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$refs	_jc_java_util_LinkedHashMap__24LinkedHashEntry$refs;
typedef struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$nonrefs	_jc_java_util_LinkedHashMap__24LinkedHashEntry$nonrefs;
typedef struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object	_jc_java_util_LinkedHashMap__24LinkedHashEntry$object;

typedef const struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vmethods	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vmethods;
typedef const struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vtable	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vtable;
typedef const struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vtype	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vtype;

// Constructors
extern void _jc_java_util_LinkedHashMap__24LinkedHashEntry$method$_init$3cf7d40480cd3150(_jc_env *, struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object *, struct _jc_java_util_LinkedHashMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern void _jc_java_util_LinkedHashMap__24LinkedHashEntry$method$access$a7b2f2b6a49a986e(_jc_env *, struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object *);
extern struct _jc_java_lang_Object$object *_jc_java_util_LinkedHashMap__24LinkedHashEntry$method$cleanup$29f5c03afa429a93(_jc_env *, struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object *);

// Virtual method descriptors
extern _jc_method _jc_java_util_LinkedHashMap__24LinkedHashEntry$method_info$access$a7b2f2b6a49a986e;
extern _jc_method _jc_java_util_LinkedHashMap__24LinkedHashEntry$method_info$cleanup$29f5c03afa429a93;

// Virtual methods structure
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vmethods {
	void	(*access$a7b2f2b6a49a986e)(_jc_env *, struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object *);
	struct _jc_java_lang_Object$object	*(*cleanup$29f5c03afa429a93)(_jc_env *, struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object *);
};

// Vtable
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods	java_util_AbstractMap__24BasicMapEntry;
	_jc_java_util_HashMap__24HashEntry$vmethods	java_util_HashMap__24HashEntry;
	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vmethods	java_util_LinkedHashMap__24LinkedHashEntry;
};

// Vtype
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vtype {
	_jc_type			type;
	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_refs {
	struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object	*pred;
	struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object	*succ;
	struct _jc_java_util_LinkedHashMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$refs {
    _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_refs	java_util_LinkedHashMap__24LinkedHashEntry;
    _jc_java_util_HashMap__24HashEntry$sub_refs	java_util_HashMap__24HashEntry;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_util_HashMap__24HashEntry$sub_nonrefs	java_util_HashMap__24HashEntry;
    _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_nonrefs	java_util_LinkedHashMap__24LinkedHashEntry;
};

// Object instance structure
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object {
	_jc_java_util_LinkedHashMap__24LinkedHashEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vtype	*vtype;
	_jc_java_util_LinkedHashMap__24LinkedHashEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_LinkedHashMap__24LinkedHashEntry$vtype _jc_java_util_LinkedHashMap__24LinkedHashEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_LinkedHashMap__24LinkedHashEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_LinkedHashMap__24LinkedHashEntry$class_object;

#endif	/* _JC_java_util_LinkedHashMap__24LinkedHashEntry_H_ */

==> jc-1.4.5.tar.gz: java/util/LinkedHashMap__24LinkedHashEntry.h <==
// class java.util.LinkedHashMap$LinkedHashEntry

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 166fe0b0ec37f0c9 java_util_AbstractMap__24BasicMapEntry
// @dep_class 5ed7b26c5166f525 java_util_HashMap__24HashEntry
// @dep_class 773b37c7a42544c8 java_util_LinkedHashMap__24LinkedHashEntry

// header file dependencies
// @dep_header java_util_HashMap__24HashEntry

#include "java/util/HashMap__24HashEntry.h"

#ifndef _JC_java_util_LinkedHashMap__24LinkedHashEntry_H_
#define _JC_java_util_LinkedHashMap__24LinkedHashEntry_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_LinkedHashMap$object;
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object;

// Typedefs
typedef struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_refs	_jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_refs;
typedef struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_nonrefs	_jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_nonrefs;
typedef struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$refs	_jc_java_util_LinkedHashMap__24LinkedHashEntry$refs;
typedef struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$nonrefs	_jc_java_util_LinkedHashMap__24LinkedHashEntry$nonrefs;
typedef struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object	_jc_java_util_LinkedHashMap__24LinkedHashEntry$object;

typedef const struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vmethods	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vmethods;
typedef const struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vtable	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vtable;
typedef const struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vtype	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vtype;

// Constructors
extern void _jc_java_util_LinkedHashMap__24LinkedHashEntry$method$_init$3cf7d40480cd3150(_jc_env *, struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object *, struct _jc_java_util_LinkedHashMap$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_util_LinkedHashMap__24LinkedHashEntry$method$access$a7b2f2b6a49a986e(_jc_env *, struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_java_util_LinkedHashMap__24LinkedHashEntry$method$cleanup$29f5c03afa429a93(_jc_env *, struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_util_LinkedHashMap__24LinkedHashEntry$method_info$access$a7b2f2b6a49a986e;
extern _jc_method _jc_java_util_LinkedHashMap__24LinkedHashEntry$method_info$cleanup$29f5c03afa429a93;

// Virtual methods structure
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vmethods {
	void	(*access$a7b2f2b6a49a986e)(_jc_env *, struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*cleanup$29f5c03afa429a93)(_jc_env *, struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_AbstractMap__24BasicMapEntry$vmethods	java_util_AbstractMap__24BasicMapEntry;
	_jc_java_util_HashMap__24HashEntry$vmethods	java_util_HashMap__24HashEntry;
	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vmethods	java_util_LinkedHashMap__24LinkedHashEntry;
};

// Vtype
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$vtype {
	_jc_type			type;
	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_refs {
	struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object	*pred;
	struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object	*succ;
	struct _jc_java_util_LinkedHashMap$object	*this;
};

// Reference instance fields (object)
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$refs {
    _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_refs	java_util_LinkedHashMap__24LinkedHashEntry;
    _jc_java_util_HashMap__24HashEntry$sub_refs	java_util_HashMap__24HashEntry;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_refs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_AbstractMap__24BasicMapEntry$sub_nonrefs	java_util_AbstractMap__24BasicMapEntry;
    _jc_java_util_HashMap__24HashEntry$sub_nonrefs	java_util_HashMap__24HashEntry;
    _jc_java_util_LinkedHashMap__24LinkedHashEntry$sub_nonrefs	java_util_LinkedHashMap__24LinkedHashEntry;
};

// Object instance structure
struct _jc_java_util_LinkedHashMap__24LinkedHashEntry$object {
	_jc_java_util_LinkedHashMap__24LinkedHashEntry$refs	refs[0];
	_jc_word		lockword;
	_jc_java_util_LinkedHashMap__24LinkedHashEntry$vtype	*vtype;
	_jc_java_util_LinkedHashMap__24LinkedHashEntry$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_util_LinkedHashMap__24LinkedHashEntry$vtype _jc_java_util_LinkedHashMap__24LinkedHashEntry$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_util_LinkedHashMap__24LinkedHashEntry, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_util_LinkedHashMap__24LinkedHashEntry$class_object;

#endif	/* _JC_java_util_LinkedHashMap__24LinkedHashEntry_H_ */
